"""Create Test Text on a Path

# Author-Ed Johnson
# Description-Simple script to quickly create test text on a path with increasing font heights
# Date-2022-02-24
# This should be perfectly safe, but use at your own risk
#
# Feel free to use and modify as you like
# 
"""
import adsk.core, adsk.fusion, traceback

def run(context):
    ui = None
    try: 
        app = adsk.core.Application.get()
        ui = app.userInterface

        # text to use for testing - don't get too long-winded or the text will exceed the arc
        testString = 'Text - 1a 2b 3j 4Q 5G 6*'
        
        # font to test - must be a valid font name on your system
        testFont = 'Arial'
        
        # test designed for Arial font
        # increase or decrease scale factor to adjust spacing and arc size (i.e. 1.1 = 110%)
        # i.e, with default text string, Arial Black needs a factor of 1.25 to scale up the arcs so the text fits
        scaleFactor = 1.0

        # Create a new document and get the Design.
        #doc = app.documents.add(adsk.core.DocumentTypes.FusionDesignDocumentType)
        design = app.activeProduct

        # Get the active component of the active design.
        component = design.activeComponent

        # Create a new sketch on the XY construction plane.
        sk = component.sketches.add(component.xYConstructionPlane)

        # Get the SketchTexts collection object.
        texts = sk.sketchTexts

        # it would be more elegant and efficient to create the arcs and place the text in a loop,
        # but this is meant to be quick and dirty and this is easier to read, understand, and edit
        
        # Draw the arcs to create paths for the text on a path.
        # point coordinates are X,Y,Z and expressed in centimeters
        # the 3 points are start point, any point along arc, end point

        arc0 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-2 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0, 2 * scaleFactor, 0),
                                                        adsk.core.Point3D.create(2 * scaleFactor, 0, 0))
        arc1 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-2.5 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0, 2.5 * scaleFactor, 0),
                                                        adsk.core.Point3D.create(2.5 * scaleFactor, 0, 0))
        arc2 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-3.25 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0,3.25 * scaleFactor,0),
                                                        adsk.core.Point3D.create(3.25 * scaleFactor, 0, 0))
        arc3 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-4.25 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0,4.25 * scaleFactor,0),
                                                        adsk.core.Point3D.create(4.25 * scaleFactor, 0, 0))
        arc4 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-5.25 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0,5.25 * scaleFactor,0),
                                                        adsk.core.Point3D.create(5.25 * scaleFactor, 0, 0))
        arc5 = sk.sketchCurves.sketchArcs.addByThreePoints(adsk.core.Point3D.create(-6.5 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(0,6.5 * scaleFactor,0),
                                                        adsk.core.Point3D.create(6.5 * scaleFactor, 0, 0))
        # set inner arcs as construction lines
        # arc0 and arc5 define the outer boundaries of the profile, so they are not construction lines.
        arc0.isConstruction = False
        arc1.isConstruction = True
        arc2.isConstruction = True
        arc3.isConstruction = True
        arc4.isConstruction = True
        arc5.isConstruction = False

        # draw line along the bottom of the largest arc so we have a closed profile to extrude
        line1 = sk.sketchCurves.sketchLines.addByTwoPoints(adsk.core.Point3D.create(-6.5 * scaleFactor, 0, 0),
                                                        adsk.core.Point3D.create(6.5 * scaleFactor, 0, 0))

        # Define text inputs to place along the arcs
        # input values are the text string and the font height (expressed in centimeters)
        # only 4 inputs to define since text is only placed on arcs 1-4
		
        input1 = texts.createInput2('4 mm ' + testString, 0.4)
        input1.setAsAlongPath(arc1, True, adsk.core.HorizontalAlignments.CenterHorizontalAlignment, 0)
        input1.isHorizontalFlip = False
        input1.isVerticalFlip = False
        input1.fontName = testFont

        input2 = texts.createInput2('5 mm ' + testString, 0.5)
        input2.setAsAlongPath(arc2, True, adsk.core.HorizontalAlignments.CenterHorizontalAlignment, 0)
        input2.isHorizontalFlip = False
        input2.isVerticalFlip = False
        input2.fontName = testFont

        input3 = texts.createInput2('6 mm ' + testString, 0.6)
        input3.setAsAlongPath(arc3, True, adsk.core.HorizontalAlignments.CenterHorizontalAlignment, 0)
        input3.isHorizontalFlip = False
        input3.isVerticalFlip = False
        input3.fontName = testFont

        input4 = texts.createInput2('8 mm ' + testString, 0.8)
        input4.setAsAlongPath(arc4, True, adsk.core.HorizontalAlignments.CenterHorizontalAlignment, 0)
        input4.isHorizontalFlip = False
        input4.isVerticalFlip = False
        input4.fontName = testFont

        # place the text on the arc paths
        texts.add(input1)        
        texts.add(input2)        
        texts.add(input3)        
        texts.add(input4)        
        
    # traceback error handler
	except:
        if ui:
            ui.messageBox('Failed:\n{}'.format(traceback.format_exc()))
